@@ -1,6 +1,6 @@
 function timeline(json){
 
-  var nodes = json.nodes,
+  var periods = json.periods,
       options = json.options,
 
       defaultShape = "Circle", // node shape by default
@@ -9,6 +9,15 @@ function timeline(json){
       selectedGroups, // temporarily selected in checkboxes
       filter = false; // global filter
 
+  var renderTime = function(t){
+    return formatter(t);
+  }
+  if(options.POSIXct){
+    renderTime = function(t){
+      return (new Date(t*1000)).toUTCString();
+    }
+  }
+
   var body = d3.select("body");
 
   var infoPanel = displayInfoPanel();
@@ -33,7 +42,7 @@ function timeline(json){
       applyCheckBoxes();
       return;
     }
-    if(d3.event.ctrlKey && key == "x"){
+    if((d3.event.ctrlKey || d3.event.metaKey) && key == "x"){
       body.selectAll(".tooltip.fixed").remove();
       infoPanel.close();
       return;
@@ -43,29 +52,27 @@ function timeline(json){
   // default linear scale for events
   options.colorScaleeventColor = "WhBu";
 
-  // sort nodes by start
-  nodes.sort(function(nodea, nodeb){
-    var a = nodea[options.start],
-        b = nodeb[options.start];
-    return a < b ? -1 : a > b ? 1 : a >= b ? 0 : NaN;
+  // sort periods by start
+  periods.sort(function(nodea, nodeb){
+    return sortAsc(nodea[options.start],nodeb[options.start]);
   });
 
   // prepare events
   if(json.events){
     var events = {};
     json.events.forEach(function(d,i){
-      if(typeof events[d[options.eventParent]] == "undefined")
-        events[d[options.eventParent]] = [];
-      events[d[options.eventParent]].push(i);
+      if(typeof events[d[options.eventPeriod]] == "undefined")
+        events[d[options.eventPeriod]] = [];
+      events[d[options.eventPeriod]].push(i);
     })
-    nodes.forEach(function(node){
+    periods.forEach(function(node){
       if(events.hasOwnProperty(node[options.name]))
         node['_events_'] = events[node[options.name]].map(function(i){ return json.events[i]; });
     });
   }
 
   // split multivariables
-  nodes.forEach(function(d){
+  periods.forEach(function(d){
       for(var p in d) {
         if(p!=options.name){
           if(typeof d[p] == "string" && d[p].indexOf("|")!=-1){
@@ -76,10 +83,10 @@ function timeline(json){
   });
 
   // top bar
-  var topBar = body.append("div")
-        .attr("class","topbar fixed-topbar")
+  var topBar = displayTopBar().fixed(true);
+  body.call(topBar);
 
-  topBar.call(iconButton()
+  topBar.addIcon(iconButton()
         .alt("pdf")
         .width(24)
         .height(24)
@@ -87,7 +94,7 @@ function timeline(json){
         .title(texts.pdfexport)
         .job(svg2pdf));
 
-  topBar.call(iconButton()
+  topBar.addIcon(iconButton()
         .alt("svg")
         .width(24)
         .height(24)
@@ -95,36 +102,36 @@ function timeline(json){
         .title(texts.svgexport)
         .job(svgDownload));
 
-  // multigraph
-  if(typeof multiGraph != 'undefined'){
-      topBar.append("h3").text(texts.graph + ":")
-      multiGraph.graphSelect(topBar);
-  }
-
   // groups selection in topBar
-  topBarVisual(topBar,"Group","group",getOptions(nodes));
+  topBar.addBox(function(box){
+    topBarVisual(box,"Group","group",getOptions(periods));
+  })
 
   if(json.events){
     // event colors in topBar
-    topBarVisual(topBar,"Color","eventColor",getOptions(json.events),displayPicker);
+    topBar.addBox(function(box){
+      topBarVisual(box,"Color","eventColor",getOptions(json.events),displayPicker);
+    });
     // event shapes in topBar
-    topBarVisual(topBar,"Shape","eventShape",getOptions(json.events));
+    topBar.addBox(function(box){
+      topBarVisual(box,"Shape","eventShape",getOptions(json.events));
+    });
   }
 
   // node filter in topBar
   var topFilterInst = topFilter()
-    .data(nodes)
-    .datanames(getOptions(nodes))
+    .data(periods)
+    .datanames(getOptions(periods))
     .attr(options.name)
     .displayGraph(displayGraph);
-  topBar.call(topFilterInst);
 
-  topBar.append("span").attr("class","separator");
+  topBar.addBox(topFilterInst);
 
-  // expand/collpse bars displaying
-  topBar.append("h3")
+  // expand/collapse bars displaying
+  topBar.addBox(function(box){
+    box.append("h3")
     .text(texts.expand)
-  topBar.append("button")
+    box.append("button")
     .attr("class","switch-button")
     .classed("active",!options.collapse)
     .on("click",function(){
@@ -132,11 +139,11 @@ function timeline(json){
       d3.select(this).classed("active",!options.collapse);
       displayGraph();
     })
-
-  topBar.append("span").attr("class","separator");
+  });
 
   // reset button
-  topBar.append("button")
+  topBar.addBox(function(box){
+      box.append("button")
         .attr("class","primary reset")
         .text(texts.reset)
         .on("click",function(){
@@ -144,6 +151,7 @@ function timeline(json){
         })
         .append("title")
           .text("F5")
+  });
 
   var header = body.append("div")
         .attr("class","header")
@@ -193,21 +201,21 @@ function timeline(json){
       }
     });
 
-    var currentYear = new Date().getFullYear(),
+    var currentTime = options.POSIXct ? Math.floor(Date.now() / 1000) : new Date().getFullYear(),
         getEnd = function(y){
-          return y === null ? currentYear : y;
+          return y === null ? currentTime : y;
         };
 
-    var items = (filter ? nodes.filter(function(d){ return filter.indexOf(d[options.name])!=-1; }) : nodes).filter(function(d){ return d[options.group]!==null; });
+    var items = (filter ? periods.filter(function(d){ return filter.indexOf(d[options.name])!=-1; }) : periods).filter(function(d){ return d[options.group]!==null; });
 
-    var lanes = options.group?d3.set(items.map(function(d){ return String(d[options.group]); })).values().sort():[""],
+    var lanes = options.group?d3.set(items.map(function(d){ return String(d[options.group]); })).values().sort(sortAsc):[""],
         laneLength = lanes.length,
         timeBegin = d3.min(items,function(d){ return d[options.start]; }),
         timeEnd = d3.max(items,function(d){ return getEnd(d[options.end]); });
 
     if(!options.text){
       items.forEach(function(d){
-        d["text"] = d[options.name]+" </br>"+d[options.start]+((d[options.end]===null)?"":" - "+d[options.end]);
+        d["text"] = d[options.name]+" </br>"+renderTime(d[options.start])+((d[options.end]===null)?"":" - "+renderTime(d[options.end]));
       })
       options.text = "text";
     }
@@ -225,7 +233,7 @@ function timeline(json){
       }else{
         var eventColorScale = d3.scaleOrdinal()
           .range(categoryColors)
-          .domain(d3.map(json.events,function(d){ return d[options.eventColor]; }).keys().sort())
+          .domain(d3.map(json.events,function(d){ return d[options.eventColor]; }).keys().sort(sortAsc))
       }
     }
 
@@ -283,7 +291,7 @@ function timeline(json){
             })
           }
         });
-        d3.set(values).values().sort().reverse().forEach(function(d){
+        d3.set(values).values().sort(sortAsc).reverse().forEach(function(d){
           var g = lcolor.append("g")
           g.append("rect")
             .attr("x",0)
@@ -314,7 +322,7 @@ function timeline(json){
             })
           }
         });
-        d3.set(values).values().sort().reverse().forEach(function(d){
+        d3.set(values).values().sort(sortAsc).reverse().forEach(function(d){
           var g = lshape.append("g")
           g.append("path")
             .attr("transform","translate(0,-5)")
@@ -338,7 +346,7 @@ function timeline(json){
     if(options.group){
       color = d3.scaleOrdinal()
         .range(categoryColors)
-        .domain(nodes.map(function(n){ return n[options.group]; }).sort());
+        .domain(periods.map(function(n){ return n[options.group]; }).sort(sortAsc));
 
       getMiniY = function(d){ return y2((lanes.indexOf(String(d[options.group]))) + 0.5) - 5; }
     }else{
@@ -502,7 +510,7 @@ function timeline(json){
     }
 
     //mini axis
-    var xAxis = d3.axisBottom(x).tickFormat(formatter);
+    var xAxis = d3.axisBottom(x).tickFormat(renderTime);
 
     mini.append("g")
       .attr("class", "x axis")
@@ -613,53 +621,52 @@ function timeline(json){
 
     // dotted vertical guide
     var rect = plot.node().getBoundingClientRect(),
-        yearGuideTop = rect.top
+        timeGuideTop = rect.top
           + topSVG.node().clientHeight
           + timeHeader.node().clientHeight
           + 3,
-        yearGuide = plot.append("div")
-      .attr("class","year-guide")
+        timeGuide = plot.append("div")
+      .attr("class","time-guide")
       .style("position","absolute")
-      .style("top",yearGuideTop+"px")
+      .style("top",timeGuideTop+"px")
       .style("left",((w/2)+margin[3])+"px")
       .style("width",0)
       .style("height",0)
       .style("border-left","dashed 1px "+basicColors.black)
       .style("z-index",-1);
 
-    var pYear = plot.append("p")
-      .attr("class","year")
+    var pTime = plot.append("p")
+      .attr("class","time")
       .style("background-color",basicColors.white)
       .style("position","absolute")
-      .style("top",yearGuideTop+"px")
+      .style("top",timeGuideTop+"px")
       .style("margin-left","-16px")
-      .style("padding","2px 0")
+      .style("padding","2px 4px")
       .style("border-radius","0 0 5px 5px")
-      .style("width","32px")
       .style("text-align","center");
 
     body.on("mousemove",function(){
       var coords = d3.mouse(body.node());
-      if(coords[1]>yearGuideTop && coords[0]>margin[3] && coords[0]<(margin[3]+w)){
-        yearGuide.style("left",coords[0]+"px");
-        pYear.style("left",coords[0]+"px");
-        var year = parseInt(x1.invert(coords[0]-margin[3]));
-        pYear.text(year);
+      if(coords[1]>timeGuideTop && coords[0]>margin[3] && coords[0]<(margin[3]+w)){
+        timeGuide.style("left",coords[0]+"px");
+        pTime.style("left",coords[0]+"px");
+        var time = parseInt(x1.invert(coords[0]-margin[3]));
+        pTime.text(renderTime(time));
       }
     })
 
     window.onscroll = function(){
-      if(window.pageYOffset > (yearGuideTop - topBar.node().offsetHeight)){
+      if(window.pageYOffset > (timeGuideTop - topBar.height())){
         timeHeader.style("position","fixed")
-          .style("top",(topBar.node().offsetHeight)+"px")
+          .style("top",(topBar.height())+"px")
           .style("left",0)
-        pYear.style("position","fixed")
-          .style("top",(topBar.node().offsetHeight + margin[2]+10)+"px")
+        pTime.style("position","fixed")
+          .style("top",(topBar.height() + margin[2]+10)+"px")
       }else{
         timeHeader.style("position",null)
           .style("top",null)
-        pYear.style("position","absolute")
-          .style("top",yearGuideTop+"px")
+        pTime.style("position","absolute")
+          .style("top",timeGuideTop+"px")
       }
     }
 
@@ -672,10 +679,10 @@ function timeline(json){
 
     function keyflip(){
       if(!d3.event.button && (d3.event.ctrlKey || d3.event.metaKey)){
-        if(window.pageYOffset>yearGuideTop){
+        if(window.pageYOffset>timeGuideTop){
           zoomArea.style("top",margin[2]+"px");
         }else{
-          zoomArea.style("top",(yearGuideTop-window.pageYOffset)+"px");
+          zoomArea.style("top",(timeGuideTop-window.pageYOffset)+"px");
         }
         zoomArea.style("display","block");
       }else{
@@ -697,7 +704,7 @@ function timeline(json){
       x1.domain([minExtent, maxExtent]);
 
       if(minExtent < maxExtent){
-        var x1Axis = d3.axisTop(x1).tickFormat(formatter);
+        var x1Axis = d3.axisTop(x1).tickFormat(renderTime);
         timeHeader.select("g").call(x1Axis);
       }else{
         timeHeader.select("g").selectAll("*").remove();
@@ -759,7 +766,7 @@ function timeline(json){
             else
               self.attr("text-anchor",null);
 
-            if(options.eventColor && options.eventColor==options.eventParent)
+            if(options.eventColor && options.eventColor==options.eventPeriod)
               self.style("fill",eventColorScale(d[options.name]));
           });
 
@@ -767,7 +774,7 @@ function timeline(json){
             if(!d['_events_'])
               return;
 
-            var points = d3.select(this).selectAll(".event").data(d['_events_'],function(dd){ return dd[options.eventChild]; });
+            var points = d3.select(this).selectAll(".event").data(d['_events_'],function(dd){ return dd[options.eventNames]; });
 
             var pointsEnter = points.enter()
                   .append("path")
@@ -783,9 +790,9 @@ function timeline(json){
               }else{
                 for(var s in d){
                   if(d.hasOwnProperty(s)){
-                    if(s==options.eventParent){
+                    if(s==options.eventPeriod){
                       continue;
-                    }else if(s==options.eventChild){
+                    }else if(s==options.eventNames){
                       html = d[s]+"<br>"+html;
                     }else if(d[s]){
                       html += s+": "+d[s]+"<br>";
@@ -857,7 +864,7 @@ function timeline(json){
       });
 
       var guideHeight = (parseInt(plot.style("height")) - parseInt(plot.select(".plot>svg:first-child").style("height"))) + "px";
-      yearGuide.style("height",guideHeight);
+      timeGuide.style("height",guideHeight);
 
     }
   }
@@ -941,10 +948,11 @@ function timeline(json){
     }
   }
 
-  function topBarVisual(sel, visual, option, opt, picker){
-    sel.append("h3").text(texts[visual] + ":")
+  function topBarVisual(div, visual, option, opt, picker){
 
-    var visualSelect = sel.append("div")
+    div.append("h3").text(texts[visual] + ":")
+
+    var visualSelect = div.append("div")
       .attr("class","select-wrapper")
     .append("select")
     .on("change",function(){
